@@ -81,11 +81,24 @@ class LazyTableHandle:
 
     async def get_records(
         self,
-        filter_dict: Optional[Dict[str, Any]] = None,
+        filter: Optional[Dict[str, Any]] = None,
         limit: int = 100,
         skip: int = 0
     ) -> List[Dict[str, Any]]:
         handle = await self._ensure_resolved()
+        filter_dict = None
+        if filter:
+            if "filterSet" not in filter:
+                filter_set = []
+                for key, value in filter.items():
+                    filter_set.append({
+                        "fieldName": key,
+                        "operator": "is",
+                        "value": value,
+                    })
+                filter_dict = {"filterSet": filter_set, "conjunction": "and"}
+            else:
+                filter_dict = filter
         return await handle.get_records(filter_dict, limit, skip)
 
     async def update_record(self, record_id: str, fields: Dict[str, Any]) -> Dict[str, Any]:
@@ -142,10 +155,24 @@ class TableHandle:
 
     async def get_records(
         self,
-        filter_dict: Optional[Dict[str, Any]] = None,
+        filter: Optional[Dict[str, Any]] = None,
         limit: int = 100,
         skip: int = 0
     ) -> List[Dict[str, Any]]:
+        filter_dict = None
+        if filter:
+            # Если это «короткий» словарь вида {"client_id": "foo", "status": "active"}
+            if "filterSet" not in filter:
+                filter_set = []
+                for key, value in filter.items():
+                    filter_set.append({
+                        "fieldName": key,
+                        "operator": "is",
+                        "value": value,
+                    })
+                filter_dict = {"filterSet": filter_set, "conjunction": "and"}
+            else:
+                filter_dict = filter
         return await self._client.get_records(self.base_id, self.table_id, filter_dict, limit, skip)
 
     async def update_record(self, record_id: str, fields: Dict[str, Any]) -> Dict[str, Any]:
@@ -420,7 +447,7 @@ class TableClient:
         self,
         base_id: str,
         table_id: str,
-        filter_dict: Optional[Dict[str, Any]] = None,
+        filter: Optional[Dict[str, Any]] = None,
         limit: int = 100,
         skip: int = 0
     ) -> List[Dict[str, Any]]:
@@ -431,7 +458,7 @@ class TableClient:
                 json={
                     "base_id": base_id,
                     "table_id": table_id,
-                    "filter": filter_dict,
+                    "filter": filter,
                     "limit": limit,
                     "skip": skip
                 }
@@ -610,12 +637,12 @@ async def batch_create_records(
 async def get_records(
     base_id: str,
     table_id: str,
-    filter_dict: Optional[Dict[str, Any]] = None,
+    filter: Optional[Dict[str, Any]] = None,
     limit: int = 100,
     skip: int = 0
 ) -> List[Dict[str, Any]]:
     client = await ensure_table_client()
-    return await client.get_records(base_id, table_id, filter_dict, limit, skip)
+    return await client.get_records(base_id, table_id, filter, limit, skip)
 
 
 async def update_record(
@@ -788,11 +815,11 @@ class _TableProxy:
         self,
         base_id: str,
         table_id: str,
-        filter_dict: Optional[Dict[str, Any]] = None,
+        filter: Optional[Dict[str, Any]] = None,
         limit: int = 100,
         skip: int = 0
     ) -> List[Dict[str, Any]]:
-        return await get_records(base_id, table_id, filter_dict, limit, skip)
+        return await get_records(base_id, table_id, filter, limit, skip)
     
     async def update_record(
         self,
